mysql.stmt.bind_in.Base_In_Stream

Package mysql :: Package stmt :: Module bind_in :: Class Base_In_Stream |
[hide private]
[frames] | no frames]

# Class Base_In_Stream

    object --+
             |
    Input_Bind --+
                 |
                Base_In_Stream

Known Subclasses:
  In_Blob, In_Long_Blob, In_Medium_Blob, In_Tiny_Blob

Base class for streaming input.

The constructor takes the following arguments:

- `who`: The object from which to read the value.
- `what`: The name of the parameter in the object to read.
- `use_stream`: If True, sets `who.what` to a stream object (Input_Stream) that has a `write` method. If False, then it assumes the value is just a string. Defaults to False.

Instance Methods | [hide private]
`` | __init__(...) x.__init__(...) initializes x; see x.__class__.__doc__ for signature
`` | __new__(T, S, ...) Returns a new object with type S, a subtype of T...
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
`` | __pyx_vtable__ = `<PyCObject object at 0x852e578>`

Instance Variables | [hide private]
`` | _max_size The maximum size of the column (based on the column type).
`` | _param_num The parameter number in the statement.
`` | _raise_error A callable object that will raise the appropriate MySQL exception (from mysql.stmt.Statement._raise_error).
`` | _stmt MYSQL_STMT structure.
`` | _stream The Input_Stream instance.
`` | _use_stream Whether or not to use a stream or just a string.
Inherited from `Input_Bind` (private): `_buffer`, `_buffer_length`, `_buffer_type`, `_is_null`, `_is_unsigned`, `_length`, `_what`, `_who`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(...) (Constructor) |
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: Input_Bind.__init__

### __new__(T, S, ...) |
    Returns:
        a new object with type S, a subtype of T
Overrides: Input_Bind.__new__

Class Variable Details | [hide private]

    ### __pyx_vtable__ Value:
        <PyCObject object at 0x852e578>

Instance Variable Details | [hide private]

### _max_size The maximum size of the column (based on the column type). (C only.)

### _param_num The parameter number in the statement. (C only.)

### _raise_error A callable object that will raise the appropriate MySQL exception (from mysql.stmt.Statement._raise_error). (C only.)

### _stmt MYSQL_STMT structure. (C only.)

### _stream The Input_Stream instance. This is created even if _use_stream is False, in which case the `set_value` method will call `write` for the user. (C only.)

### _use_stream Whether or not to use a stream or just a string. (C only.)